@@ -15,8 +15,7 @@
 package com.google.api.client.auth.oauth2;
 
 import com.google.api.client.json.JsonFactory;
-import com.google.api.client.json.jackson.JacksonFactory;
-
+import com.google.api.client.json.gson.GsonFactory;
 import junit.framework.TestCase;
 
 /**
@@ -26,12 +25,13 @@ import junit.framework.TestCase;
  */
 public class TokenErrorResponseTest extends TestCase {
 
-  private static final String JSON = "{\"error\":\"invalid_request\","
-      + "\"error_uri\":\"http://www.example.com/error\","
-      + "\"error_description\":\"error description\"}";
+  private static final String JSON =
+      "{\"error\":\"invalid_request\","
+          + "\"error_uri\":\"http://www.example.com/error\","
+          + "\"error_description\":\"error description\"}";
 
   public void test() throws Exception {
-    JsonFactory jsonFactory = new JacksonFactory();
+    JsonFactory jsonFactory = new GsonFactory();
     TokenErrorResponse response = jsonFactory.fromString(JSON, TokenErrorResponse.class);
     assertEquals("invalid_request", response.getError());
     assertEquals("http://www.example.com/error", response.getErrorUri());
